package webapp.issue12796;

import java.util.Arrays;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.management.MBeanServer;
import javax.management.ObjectName;
import javax.servlet.ServletContextEvent;
import javax.servlet.ServletContextListener;

public class MyContextListener implements ServletContextListener {
    static final Logger log = Logger.getAnonymousLogger();

    public MyContextListener() {
        log.info("MyContextListener: constructor");
    }

    @Override
    public void contextInitialized(ServletContextEvent sce) {
        log.info("MyContextListener: contextInitialized");
        try {
            MBeanServer mbs = (javax.management.MBeanServer) javax.management.MBeanServerFactory.findMBeanServer(null).iterator().next();
            // start AMX
            log.info("MyContextListener: start AMX");
            mbs.invoke(new ObjectName("amx-support:type=boot-amx"), "bootAMX", new Object[0], new String[0]);
            log.info("MyContextListener: AMX started");
            // get version
            String version = (String) mbs.getAttribute(new ObjectName("amx:pp=/J2EEDomain,type=J2EEServer,name=server,j2eeType=J2EEServer"), "serverVersion");
            log.info("MyContextListener: version=" + version);
            // do version-specific stuff, e.g. file-realm user management
            String[] users = (String[]) mbs.invoke(new ObjectName("amx:pp=/ext,type=realms"), "getUserNames", new Object[]{"file"}, new String[]{"java.lang.String"});
            log.info("MyContextListener: users=" + Arrays.asList(users).toString());
        } catch (Exception e) {
            log.log(Level.SEVERE, "MyContextListener: context initialization failed", e);
        }
    }

    @Override
    public void contextDestroyed(ServletContextEvent sce) {
        log.info("MyContextListener: contextDestroyed");
    }


}
